@@ -66,11 +66,14 @@ func (i interpreter) executeShebang(
 ) error {
 	f, err := os.CreateTemp("", i.tempFilePrefix)
 	if err != nil {
-		return fmt.Errorf("failed to create execution file")
+		return fmt.Errorf("failed to create execution file: %w", err)
 	}
 	defer os.Remove(f.Name())
 	if _, err = f.WriteString(text); err != nil {
-		return fmt.Errorf("failed to write execution file")
+		return fmt.Errorf("failed to write execution file: %w", err)
+	}
+	if err := f.Close(); err != nil {
+		return fmt.Errorf("failed to close execution file: %w", err)
 	}
 	interpreterArgs = append(interpreterArgs, f.Name())
 	cmd := exec.CommandContext(ctx, interpreterCmd, append(interpreterArgs, args...)...)
@@ -100,9 +103,6 @@ func (i interpreter) executeShell(
 	if err != nil {
 		return fmt.Errorf("failed to parse task: %w", err)
 	}
-	// Ignore G115: Potential integer overflow when converting between integer types
-	// "Fd()" ultimately returns a SysFd value, which is an int.
-	//nolint:gosec
 	if os.Getenv("NO_COLOR") != "1" && term.IsTerminal(int(os.Stdout.Fd())) {
 		env = append(env, "CLICOLOR_FORCE=1", "FORCE_COLOR=1")
 	}
